@@ -289,6 +289,80 @@ def restore_cookies(driver, cookie_file, path = '/', domain = '.mercari.com'):
 
 
 
+def chrome_login(login_dict):
+
+    username = login_dict.get('username', None)
+    password = login_dict.get('password', None)
+    userdata_path = login_dict.get('userdata_path', None)
+    login_url = login_dict.get('login_url', None)
+    login_el = login_dict.get('login_el', None)
+    login_success_url = login_dict.get('login_success_url', None)
+    login_success_el = login_dict.get('login_success_el', None)
+    login_button_el = login_dict.get('login_button_el', None)
+    username_el = login_dict.get('username_el', None)
+    password_el = login_dict.get('password_el', None)
+    recaptcha_el = login_dict.get('recaptcha_el', None)
+    cookie_file = login_dict.get('cookie_file', None)
+    cookie_path = login_dict.get('cookie_path', '/')
+    cookie_domain = login_dict.get('cookie_domain', None)
+    username_login_button_el = login_dict.get('username_login_button_el', None)
+
+    login_done = False
+    driver = chrome_open(userdata_path=userdata_path)
+    if os.path.exists(cookie_file):
+        chrome_get_url(driver, login_url, login_el)
+        restore_cookies(driver,  cookie_file, path=cookie_path, domain=cookie_domain)
+        print("Check whether has login")
+        driver.get(login_success_url)
+        for i in range(9):
+            sleep(1)
+            try:
+                driver.find_element_by_xpath(login_success_el) #我的页面
+                login_done = True
+                save_cookies(driver, f'{username}_cookie.pickle')
+                print("login succeed")
+                break
+            except:
+                pass
+
+            try:
+                driver.find_element_by_xpath(login_button_el) # 登录按钮
+                login_done = False
+                break
+            except:
+                pass
+        else:
+            raise Exception("cant open url")
+
+
+
+    if login_done is False:
+        driver.get(login_url)
+        if username_login_button_el is not None:
+            wait_find_element(driver, '//*[@id="J-loginMethod-tabs"]/li[2]').click()
+        wait_find_element(driver, username_el).clear()
+        wait_find_element(driver, username_el).send_keys(username)
+        wait_find_element(driver, password_el).clear()
+        wait_find_element(driver, password_el).send_keys(password)
+        try:
+            # check whether there is recaptcha
+            driver.find_element_by_xpath(recaptcha_el)
+            # iframe=driver.find_element_by_tag_name('iframe')
+            # driver.switch_to.frame(iframe)
+            # ActionChains(driver).click(driver.find_element_by_xpath('//*[@id="recaptcha-anchor"]/div[1]')).perform()
+            # driver.find_element_by_xpath('//*[@id="recaptcha-anchor"]/div[4]')
+            # wait_find_element(driver, '//*[@id="recaptcha-anchor"]/div[4]')
+            # driver.switch_to.default_content()
+            print("Please try to login manually")
+        except:
+            wait_find_element(driver, '/html/body/div[1]/main/div/form/div/button').click()
+        while 'login' in driver.current_url or 'passport' in driver.current_url:
+            sleep(4)
+            print("Waiting to login")
+        save_cookies(driver, cookie_file)
+
+    return driver
+
 # %%
 if __name__ == '__main__':
     print("Mission start!")
